@@ -44,7 +44,7 @@ static char buf[1024];
     if (fd == -1 && (fd = open(filename, O_RDONLY)) == -1) {	\
 	fprintf(stderr, BAD_OPEN_MESSAGE);			\
 	close(fd);						\
-	return 0;						\
+	_exit(0);						\
     }								\
     lseek(fd, 0L, SEEK_SET);					\
     if ((n = read(fd, buf, sizeof buf - 1)) < 0) {		\
@@ -103,11 +103,17 @@ static int init_Hertz_value(void){
   unsigned long user_j, nice_j, sys_j, other_j;  /* jiffies (clock ticks) */
   double up_1, up_2, seconds;
   unsigned long jiffies, h;
+  int i = 0;
   do{
     FILE_TO_BUF(UPTIME_FILE,uptime_fd);  sscanf(buf, "%lf", &up_1);
     /* uptime(&up_1, NULL); */
     FILE_TO_BUF(STAT_FILE,stat_fd);
-    sscanf(buf, "cpu %lu %lu %lu %lu", &user_j, &nice_j, &sys_j, &other_j);
+    /* If we are SMP, then the first line is the sum of jiffies by all CPUs */
+    /* In that case, skip it and use the jiffies of the first CPU instead. */
+    /* On a single-CPU machine, the 2nd sscanf should harmlessly fail. */
+    sscanf(buf, "cpu %lu %lu %lu %lu\n%n",
+	   &user_j, &nice_j, &sys_j, &other_j, &i);
+    sscanf(buf+i, "cpu0 %lu %lu %lu %lu", &user_j, &nice_j, &sys_j, &other_j);
     FILE_TO_BUF(UPTIME_FILE,uptime_fd);  sscanf(buf, "%lf", &up_2);
     /* uptime(&up_2, NULL); */
   } while((long)( (up_2-up_1)*1000.0/up_1 )); /* want under 0.1% error */
