@@ -10,6 +10,7 @@
  */
 #include <fcntl.h>
 #include <pwd.h>
+#include <dirent.h>
 #include <errno.h>
 #include <signal.h>
 #include <stdio.h>
@@ -67,12 +68,9 @@ static int program;
 #ifdef SIGSYS
 #  undef SIGUNUSED
 #  undef SIGSTKFLT
-#else
-#  warning Your header files are not standards-compliant!
 #endif
 
 #ifndef SIGRTMIN
-#  warning Your header files are not standards-compliant!
 #  define SIGRTMIN 32
 #endif
 
@@ -373,6 +371,8 @@ static void show_lists(void){
 /***** iterate over all PIDs */
 static void iterate(void){
   int pid;
+  DIR *d;
+  struct dirent *de;
   if(pids){
     pid = pid_count;
     while(pid--) check_proc(pids[pid]);
@@ -383,9 +383,13 @@ static void iterate(void){
   if(!ttys && !cmds && !pids && !i_flag){
   }
 #endif
-  /* assume PIDs range from 2 to 2**15 rather than reading /proc */
-  pid = 2;
-  while(pid<33000) check_proc(pid++);
+  if (!(d = opendir ("/proc"))) {
+    perror ("/proc"); exit (1);
+  }
+  while (de = readdir (d))
+    if (pid = atoi (de->d_name))
+	check_proc (pid);
+  closedir (d);
 }
 
 /***** kill help */
