@@ -102,6 +102,7 @@ extern int parse_sort_opt(char* opt);
 extern void register_sort_function (int dir, cmp_t func);
 
 #define PUTP(x) (tputs(x,1,putchar))
+#define BAD_INPUT -30
 
 #include "top.h"  /* new header for top specific things */
 
@@ -278,6 +279,7 @@ void setup_terminal(void)
     me = tgetstr("me", 0);
 
 
+    if (Batch) return; /* the rest doesn't apply to batch mode */
     if (tcgetattr(0, &Savetty) == -1) {
         perror(PROGNAME ": tcgetattr() failed");
 	error_end(errno);
@@ -454,7 +456,8 @@ void error_end(int rno)
 {
     if (psdbsucc)
         close_psdb();
-    tcsetattr(0, TCSAFLUSH, &Savetty);
+    if (!Batch)
+	tcsetattr(0, TCSAFLUSH, &Savetty);
     PUTP(tgoto(cm, 0, Lines - 1));
     fputs("\r\n", stdout);
     exit(rno);
@@ -466,7 +469,8 @@ void end(int signo)
 {
     if (psdbsucc)
 	close_psdb();
-    tcsetattr(0, TCSAFLUSH, &Savetty);
+    if (!Batch)
+	tcsetattr(0, TCSAFLUSH, &Savetty);
     PUTP(tgoto(cm, 0, Lines - 1));
     fputs("\r\n", stdout);
     exit(0);
@@ -478,12 +482,14 @@ void end(int signo)
 void stop(int signo)
 {
     /* Reset terminal. */
-    tcsetattr(0, TCSAFLUSH, &Savetty);
+    if (!Batch)
+	tcsetattr(0, TCSAFLUSH, &Savetty);
     PUTP(tgoto(cm, 0, Lines - 3));
     fflush(stdout);
     raise(SIGSTOP);
     /* Later... */
-    tcsetattr (0, TCSAFLUSH, &Rawtty);
+    if (!Batch)
+	tcsetattr (0, TCSAFLUSH, &Rawtty);
 }
 
 /*
@@ -560,9 +566,9 @@ char *getstr(void)
 
 
 /*
-       * Get an integer from the user.  Display an error message and return -1
-       * if it's invalid; else return the number.
-       */
+ * Get an integer from the user.  Display an error message and return BAD_INPUT
+ * if it's invalid; else return the number.
+ */
 int getint(void)
 {
     char *line;
@@ -574,13 +580,13 @@ int getint(void)
     for (i = 0; line[i]; i++) {
 	if (!isdigit(line[i]) && line[i] != '-') {
 	    SHOWMESSAGE(("That's not a number!"));
-	    return (-1);
+	    return (BAD_INPUT);
 	}
     }
 
     /* An empty line is a legal error (hah!). */
     if (!line[0])
-	return (-1);
+	return (BAD_INPUT);
 
     sscanf(line, "%d", &r);
     return (r);
@@ -601,13 +607,13 @@ float getfloat(void)
     for (i = 0; line[i]; i++) {
 	if (!isdigit(line[i]) && line[i] != '.' && line[i] != '-') {
 	    SHOWMESSAGE(("That's not a float!"));
-	    return (-1);
+	    return (BAD_INPUT);
 	}
     }
 
     /* An empty line is a legal error (hah!). */
     if (!line[0])
-	return (-1);
+	return (BAD_INPUT);
 
     sscanf(line, "%f", &r);
     return (r);
@@ -719,9 +725,11 @@ void change_order(void)
 	PUTP(tgoto(cm, 0, 1));
 	printf("Upper case characters move a field to the left, lower case to the right");
 	fflush(stdout);
-	tcsetattr(0, TCSAFLUSH, &Rawtty);
-	read(0, &c, 1);
-	tcsetattr(0, TCSAFLUSH, &Savetty);
+	if (!Batch) { /* should always be true, but... */
+	    tcsetattr(0, TCSAFLUSH, &Rawtty);
+	    read(0, &c, 1);
+	    tcsetattr(0, TCSAFLUSH, &Savetty);
+	}
 	i = toupper(c) - 'A';
 	if ((p = strchr(Fields, i + 'A')) != NULL) {
 	    if (isupper(c))
@@ -767,9 +775,11 @@ void change_fields(void)
 	PUTP(tgoto(cm, 0, 1));
 	printf("Toggle fields with a-x, any other key to return: ");
 	fflush(stdout);
-	tcsetattr(0, TCSAFLUSH, &Rawtty);
-	read(0, &c, 1);
-	tcsetattr(0, TCSAFLUSH, &Savetty);
+	if (!Batch) { /* should always be true, but... */
+	    tcsetattr(0, TCSAFLUSH, &Rawtty);
+	    read(0, &c, 1);
+	    tcsetattr(0, TCSAFLUSH, &Savetty);
+	}
 	i = toupper(c) - 'A';
 	if (i >= 0 && i < sizeof headers / sizeof headers[0]) {
 	    row = i % (Lines - 3) + 3;
@@ -1321,7 +1331,7 @@ void do_key(char c)
      * attributes always be normal?  Does it matter?  I suppose the
      * shell will be set up the way the user wants it.)
      */
-    tcsetattr(0, TCSANOW, &Savetty);
+    if (!Batch) tcsetattr(0, TCSANOW, &Savetty);
 
     /*
      * Handle the rest of the commands.
@@ -1346,7 +1356,7 @@ void do_key(char c)
 	PUTP(me);
 	fputs("\n\n", stdout);
 	printf("%s\n\nPress any key to continue", Secure ? SECURE_HELP_SCREEN : HELP_SCREEN);
-	tcsetattr(0, TCSANOW, &Rawtty);
+	if (!Batch) tcsetattr(0, TCSANOW, &Rawtty);
 	(void) getchar();
 	break;
       case 'i':
@@ -1365,7 +1375,7 @@ void do_key(char c)
 	    PUTP(md);
 	    SHOWMESSAGE(("PID to kill: "));
 	    pid = getint();
-	    if (pid == -1)
+	    if (pid == BAD_INPUT)
 		break;
 	    PUTP(top_clrtoeol);
 	    SHOWMESSAGE(("Kill PID %d with signal [15]: ", pid));
@@ -1410,7 +1420,7 @@ void do_key(char c)
       case '#':
 	printf("Processes to display (0 for unlimited): ");
 	numinput = getint();
-	if (numinput != -1) {
+	if (numinput != BAD_INPUT) {
 	    Display_procs = numinput;
 	    window_size(0);
 	}
@@ -1423,13 +1433,13 @@ void do_key(char c)
 
 	    printf("PID to renice: ");
 	    pid = getint();
-	    if (pid == -1)
+	    if (pid == BAD_INPUT)
 		break;
 	    PUTP(tgoto(cm, 0, header_lines - 2));
 	    PUTP(top_clrtoeol);
 	    printf("Renice PID %d to value: ", pid);
 	    val = getint();
-	    if (val == -1)
+	    if (val == BAD_INPUT)
 		val = 10;
 	    if (setpriority(PRIO_PROCESS, pid, val))
 		SHOWMESSAGE(("\aRenice of PID %d to %d failed: %s",
@@ -1536,7 +1546,7 @@ void do_key(char c)
     /*
      * Return to raw mode.
      */
-    tcsetattr(0, TCSANOW, &Rawtty);
+    if (!Batch) tcsetattr(0, TCSANOW, &Rawtty);
     return;
 }
 
