@@ -142,7 +142,7 @@ static proc_t *getproc(utmp_t *u, char *tty, int *jcpu, int *found_utpid) {
 	    *found_utpid = 1;
 	if ((**p).tty == line) {
 	    (*jcpu) += (**p).utime + (**p).stime;
-	    if ((!ignoreuser || !strncmp((**p).euser, u->ut_user, USERSZ)) &&
+	    if ((ignoreuser || !strncmp((**p).euser, u->ut_user, USERSZ)) &&
 		((**p).pid == (**p).tpgid && (!best || (**p).pid > best->pid)))
 		best = *p;
 	}
@@ -253,7 +253,7 @@ int main(int argc, char **argv) {
     if (maxcmd < 3)
 	fprintf(stderr, "warning: screen width %d suboptimal.\n", win.ws_col);
 
-    procs = readproctab(PROC_FILLCMD);
+    procs = readproctab(PROC_FILLCMD | PROC_FILLUSR);
 
     if (header) {				/* print uptime and headers */
 	print_uptime();
